@@ -10,7 +10,7 @@ function(f,para) {
     for(i in seq(1,n)) {
       if(f[i] == 1) { x[i] <- Inf; next }
       if(f[i] == 0) { x[i] <- -Inf; next }
-      if(f[i] == 0.5) return(U)
+      if(f[i] == 0.5) { x[i] <- U; next }
       x[i] <- U + A*tan(pi*(f[i]-0.5))
     }
     return(x)
